AsyncGetSize

Trait AsyncGetSize 

pub trait AsyncGetSize {
    // Required method
    fn poll_get_size(
        self: Pin<&mut Self>,
        cx: &mut Context<'_>,
    ) -> Poll<Result<u64>>;
}
Trait for getting the size of the file asynchronously.

Required Methods

fn poll_get_size( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Result<u64>>

Attempt to get the size of the file, on success returns the file size.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: AsyncGetSize + Unpin> AsyncGetSize for Arc<Mutex<T>>

Source

fn poll_get_size( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Result<u64, Error>>

Implementors