AsyncGetSizeExt

Trait AsyncGetSizeExt 

pub trait AsyncGetSizeExt: AsyncGetSize {
    // Provided method
    fn get_size<'a>(&'a mut self) -> GetSize<'a, Self>
       where Self: Unpin { ... }
}
An extension trait which adds utility methods to AsyncGetSize.

Provided Methods

fn get_size<'a>(&'a mut self) -> GetSize<'a, Self>
where Self: Unpin,

Returns a future that will return the file size on success.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors